@@ -30,12 +30,16 @@ def client(request):
     return r
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_bulk(client):
     with pytest.raises(NotImplementedError):
         client.graph().bulk()
         client.graph().bulk(foo="bar!")
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_graph_creation(client):
     graph = client.graph()
 
@@ -80,6 +84,8 @@ def test_graph_creation(client):
     graph.delete()
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_array_functions(client):
     query = """CREATE (p:person{name:'a',age:32, array:[0,1,2]})"""
     client.graph().query(query)
@@ -100,6 +106,8 @@ def test_array_functions(client):
     assert [a] == result.result_set[0][0]
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_path(client):
     node0 = Node(node_id=0, label="L1")
     node1 = Node(node_id=1, label="L1")
@@ -119,6 +127,8 @@ def test_path(client):
     assert expected_results == result.result_set
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_param(client):
     params = [1, 2.3, "str", True, False, None, [0, 1, 2], r"\" RETURN 1337 //"]
     query = "RETURN $param"
@@ -128,6 +138,8 @@ def test_param(client):
         assert expected_results == result.result_set
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_map(client):
     query = "RETURN {a:1, b:'str', c:NULL, d:[1,2,3], e:True, f:{x:1, y:2}}"
 
@@ -144,6 +156,8 @@ def test_map(client):
     assert actual == expected
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_point(client):
     query = "RETURN point({latitude: 32.070794860, longitude: 34.820751118})"
     expected_lat = 32.070794860
@@ -160,6 +174,8 @@ def test_point(client):
     assert abs(actual["longitude"] - expected_lon) < 0.001
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_index_response(client):
     result_set = client.graph().query("CREATE INDEX ON :person(age)")
     assert 1 == result_set.indices_created
@@ -174,6 +190,8 @@ def test_index_response(client):
         client.graph().query("DROP INDEX ON :person(age)")
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_stringify_query_result(client):
     graph = client.graph()
 
@@ -227,6 +245,8 @@ def test_stringify_query_result(client):
     graph.delete()
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_optional_match(client):
     # Build a graph of form (a)-[R]->(b)
     node0 = Node(node_id=0, label="L1", properties={"value": "a"})
@@ -251,6 +271,8 @@ def test_optional_match(client):
     graph.delete()
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_cached_execution(client):
     client.graph().query("CREATE ()")
 
@@ -268,6 +290,8 @@ def test_cached_execution(client):
     assert cached_result.cached_execution
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_slowlog(client):
     create_query = """CREATE (:Rider
     {name:'Valentino Rossi'})-[:rides]->(:Team {name:'Yamaha'}),
@@ -280,7 +304,9 @@ def test_slowlog(client):
     assert results[0][2] == create_query
 
 
+@pytest.mark.redismod
 @pytest.mark.xfail(strict=False)
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_query_timeout(client):
     # Build a sample graph with 1000 nodes.
     client.graph().query("UNWIND range(0,1000) as val CREATE ({v: val})")
@@ -294,6 +320,8 @@ def test_query_timeout(client):
         assert False is False
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_read_only_query(client):
     with pytest.raises(Exception):
         # Issue a write query, specifying read-only true,
@@ -302,6 +330,8 @@ def test_read_only_query(client):
         assert False is False
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_profile(client):
     q = """UNWIND range(1, 3) AS x CREATE (p:Person {v:x})"""
     profile = client.graph().profile(q).result_set
@@ -316,7 +346,9 @@ def test_profile(client):
     assert "Node By Label Scan | (p:Person) | Records produced: 3" in profile
 
 
+@pytest.mark.redismod
 @skip_if_redis_enterprise()
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_config(client):
     config_name = "RESULTSET_SIZE"
     config_value = 3
@@ -348,6 +380,8 @@ def test_config(client):
 
 
 @pytest.mark.onlynoncluster
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_list_keys(client):
     result = client.graph().list_keys()
     assert result == []
@@ -370,6 +404,8 @@ def test_list_keys(client):
     assert result == []
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_multi_label(client):
     redis_graph = client.graph("g")
 
@@ -395,6 +431,8 @@ def test_multi_label(client):
         assert True
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_cache_sync(client):
     pass
     return
@@ -404,7 +442,7 @@ def test_cache_sync(client):
     # Client B will try to get Client A out of sync by:
     # 1. deleting the graph
     # 2. reconstructing the graph in a different order, this will casuse
-    #    a differance in the current mapping between string IDs and the
+    #    a difference in the current mapping between string IDs and the
     #    mapping Client A is aware of
     #
     # Client A should pick up on the changes by comparing graph versions
@@ -467,6 +505,8 @@ def test_cache_sync(client):
     assert A._relationship_types[1] == "R"
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_execution_plan(client):
     redis_graph = client.graph("execution_plan")
     create_query = """CREATE
@@ -485,6 +525,8 @@ def test_execution_plan(client):
     redis_graph.delete()
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_explain(client):
     redis_graph = client.graph("execution_plan")
     # graph creation / population
@@ -573,6 +615,8 @@ Project
     redis_graph.delete()
 
 
+@pytest.mark.redismod
+@pytest.mark.skip(reason="Graph module removed from Redis Stack")
 def test_resultset_statistics(client):
     with patch.object(target=QueryResult, attribute="_get_stat") as mock_get_stats:
         result = client.graph().query("RETURN 1")
